@@ -19,7 +19,7 @@ Url = str
 Path = str
 
 REMOTE_PATH = (
-    "https://raw.githubusercontent.com/biolink/biolink-model/2.2.12/biolink-model.yaml"
+    "https://raw.githubusercontent.com/biolink/biolink-model/2.2.13/biolink-model.yaml"
 )
 RELATED_TO = "related to"
 CACHE_SIZE = 1024
@@ -42,7 +42,7 @@ class Toolkit(object):
     ) -> None:
         self.generator = ToolkitGenerator(schema)
         self.generator.serialize()
-        self.view = SchemaView(REMOTE_PATH)
+        self.view = SchemaView(schema)
 
     @lru_cache(CACHE_SIZE)
     def get_all_elements(self, formatted: bool = False) -> List[str]:
@@ -432,10 +432,14 @@ class Toolkit(object):
 
         """
         parsed_name = parse_name(name)
+        logger.debug(parsed_name)
         element = self.generator.obj_for(parsed_name)
         if element is None and name in self.generator.aliases:
+            logger.debug("in aliases")
+            logger.debug(self.generator.aliases)
             element = self.get_element(self.generator.aliases[name])
         if element is None and "_" in name:
+            logger.debug("has a _")
             element = self.get_element(name.replace("_", " "))
         return element
 
@@ -1012,7 +1016,6 @@ class Toolkit(object):
                 element = self.get_element(category)
                 if hasattr(element, 'id_prefixes') and prefix in element.id_prefixes:
                     categories.append(element.name)
-        print(categories)
         if len(categories) == 0:
             logger.warning("no biolink class found for the given curie: %s, try get_element_by_mapping?", identifier)
 
@@ -1058,10 +1061,16 @@ class Toolkit(object):
                 ancestors.append(
                     [x for x in self.get_ancestors(m, mixin)[::-1] if x in mappings]
                 )
+                logger.debug(ancestors)
+            without_empty_lists = list(filter(None, ancestors))
             common_ancestors = reduce(
-                lambda s, l: s.intersection(set(l)), ancestors[1:], set(ancestors[0])
+                lambda s, l: s.intersection(set(l)), without_empty_lists[1:], set(without_empty_lists[0])
             )
-            for a in ancestors[0]:
+            logger.debug("common_ancestors")
+            logger.debug(common_ancestors)
+            for a in without_empty_lists[0]:
+                logger.debug("ancestors[0]")
+                logger.debug(a)
                 if a in common_ancestors:
                     if formatted:
                         element = format_element(self.generator.obj_for(a))
@@ -1133,6 +1142,7 @@ class Toolkit(object):
         mappings = self.generator.exact_mappings.get(
             self.generator.namespaces.uri_for(identifier), set()
         )
+        logger.debug(mappings)
         return self._format_all_elements(mappings, formatted)
 
     @lru_cache(CACHE_SIZE)
