@@ -69,7 +69,9 @@ class ToolkitGenerator(Generator):
             self.id_prefixes[element.name].add(id_prefix)
         if element_uri:
             self.mappings[self.namespaces.uri_for(element_uri)].add(element.name)
-        self.aliases.update({a: element.name for a in element.aliases})
+
+        new_aliases = self.fix_aliases(element)
+        self.aliases.update({a: element.name for a in new_aliases})
 
     def visit_slot(self, aliased_slot_name: str, slot: SlotDefinition) -> None:
         """
@@ -85,7 +87,15 @@ class ToolkitGenerator(Generator):
 
         """
         self.visit_element(slot, slot.slot_uri)
-        self.aliases.update({a: slot.name for a in slot.aliases})
+        new_aliases = self.fix_aliases(slot)
+        self.aliases.update({a: slot.name for a in new_aliases})
+
+    def fix_aliases(self, aelement: Element):
+        if '_' in aelement.name:
+            new_aliases = []
+        else:
+            new_aliases = aelement.aliases
+        return new_aliases
 
     def visit_type(self, typ: TypeDefinition) -> None:
         """
